```{eval-rst}
.. include:: ../../Readme.md
    :parser: myst_parser.sphinx_
```

```{eval-rst}
.. toctree::
   :hidden:

   tutorials/index
   API<api/repro>
   Models<models/index>
   GitHub<https://github.com/danieldeutsch/repro>
   changelog
   License<https://raw.githubusercontent.com/danieldeutsch/repro/master/LICENSE>
```